# Copyright © 2022 Arrikto Inc.  All Rights Reserved.

"""Triton Python model.

This script defines a Triton Python model that can be used to serve a
simple Python function using the Triton Inference Server.
"""

import json

import triton_python_backend_utils as pb_utils


class TritonPythonModel:
    """A Triton Python function backend."""

    def initialize(self, args):
        """Intialize any state associated with this model."""
        self.model_config = model_config = json.loads(args['model_config'])

        # Get OUTPUT configuration
        output_config = pb_utils.get_output_config_by_name(
            model_config, "OUTPUT")

        # Convert Triton types to numpy types
        self.output_dtype = pb_utils.triton_string_to_numpy(
            output_config['data_type'])

    def execute(self, requests):
        """Execute the function."""
        output_dtype = self.output_dtype

        responses = []
        for request in requests:
            input = pb_utils.get_input_tensor_by_name(request, "INPUT")

            out = 2 * input.as_numpy() + 1
            out_tensor = pb_utils.Tensor("OUTPUT",
                                         out.astype(output_dtype))

            inference_response = pb_utils.InferenceResponse(
                output_tensors=[out_tensor])
            responses.append(inference_response)

        return responses
